interface ToolState {
    uses: number;
    max: number;
}

interface ToolInventory {
    dart: ToolState;
    hammer: ToolState;
    laser: ToolState;
}

class GameInventory {
    private static instance: GameInventory | null = null;
    private display: HTMLDivElement | null = null;
    
    private inventory: ToolInventory = {
        dart: { uses: 10, max: 10 },
        hammer: { uses: 10, max: 10 },
        laser: { uses: 10, max: 10 }
    };

    private constructor() {}

    static getInstance(): GameInventory {
        if (!GameInventory.instance) {
            GameInventory.instance = new GameInventory();
        }
        return GameInventory.instance;
    }

    initUI(container: HTMLDivElement) {
        this.display = document.createElement('div');
        this.display.style.position = 'fixed';
        this.display.style.top = '80px';
        this.display.style.right = '20px';
        this.display.style.background = 'rgba(0, 0, 0, 0.7)';
        this.display.style.padding = '10px';
        this.display.style.borderRadius = '8px';
        this.display.style.color = 'white';
        this.display.style.fontSize = '14px';
        this.display.style.zIndex = '1000';
        container.appendChild(this.display);
        this.updateUI();
    }

    private updateUI() {
        if (!this.display) return;
        
        const tools = [
            { name: 'Dart', icon: '🎯', ...this.inventory.dart },
            { name: 'Hammer', icon: '🔨', ...this.inventory.hammer },
            { name: 'Laser', icon: '⚡', ...this.inventory.laser }
        ];
        
        this.display.innerHTML = tools
            .map(tool => `
                <div style="display: flex; align-items: center; margin: 5px 0; opacity: ${tool.uses > 0 ? '1' : '0.5'}">
                    <span style="font-size: 20px; margin-right: 8px;">${tool.icon}</span>
                    <span style="flex: 1;">${tool.uses}/${tool.max}</span>
                </div>
            `).join('');
    }

    canUse(name: keyof ToolInventory): boolean {
        return this.inventory[name].uses > 0;
    }

    use(name: keyof ToolInventory): boolean {
        if (!this.canUse(name)) return false;
        this.inventory[name].uses--;
        this.updateUI();
        return true;
    }

    reset() {
        Object.values(this.inventory).forEach(tool => {
            tool.uses = tool.max;
        });
        this.updateUI();
    }
}

export const gameInventory = GameInventory.getInstance(); 